==> zio-aws-s3_2.12-5.19.7.5-sources.jar: zio/aws/s3/model/BucketLoggingStatus.scala <==
package zio.aws.s3.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class BucketLoggingStatus(
    loggingEnabled: Optional[zio.aws.s3.model.LoggingEnabled] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.BucketLoggingStatus = {
    import BucketLoggingStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.BucketLoggingStatus
      .builder()
      .optionallyWith(loggingEnabled.map(value => value.buildAwsValue()))(
        _.loggingEnabled
      )
      .build()
  }
  def asReadOnly: zio.aws.s3.model.BucketLoggingStatus.ReadOnly =
    zio.aws.s3.model.BucketLoggingStatus.wrap(buildAwsValue())
}
object BucketLoggingStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.BucketLoggingStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.BucketLoggingStatus = zio.aws.s3.model
      .BucketLoggingStatus(loggingEnabled.map(value => value.asEditable))
    def loggingEnabled: Optional[zio.aws.s3.model.LoggingEnabled.ReadOnly]
    def getLoggingEnabled
        : ZIO[Any, AwsError, zio.aws.s3.model.LoggingEnabled.ReadOnly] =
      AwsError.unwrapOptionField("loggingEnabled", loggingEnabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.BucketLoggingStatus
  ) extends zio.aws.s3.model.BucketLoggingStatus.ReadOnly {
    override val loggingEnabled
        : Optional[zio.aws.s3.model.LoggingEnabled.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loggingEnabled())
        .map(value => zio.aws.s3.model.LoggingEnabled.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.BucketLoggingStatus
  ): zio.aws.s3.model.BucketLoggingStatus.ReadOnly = new Wrapper(impl)
}

==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/BucketLoggingStatus.scala <==
package zio.aws.s3.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class BucketLoggingStatus(
    loggingEnabled: Option[zio.aws.s3.model.LoggingEnabled] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.BucketLoggingStatus = {
    import BucketLoggingStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.BucketLoggingStatus
      .builder()
      .optionallyWith(loggingEnabled.map(value => value.buildAwsValue()))(
        _.loggingEnabled
      )
      .build()
  }
  def asReadOnly: zio.aws.s3.model.BucketLoggingStatus.ReadOnly =
    zio.aws.s3.model.BucketLoggingStatus.wrap(buildAwsValue())
}
object BucketLoggingStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.BucketLoggingStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.BucketLoggingStatus = zio.aws.s3.model
      .BucketLoggingStatus(loggingEnabled.map(value => value.asEditable))
    def loggingEnabled: Option[zio.aws.s3.model.LoggingEnabled.ReadOnly]
    def getLoggingEnabled
        : ZIO[Any, AwsError, zio.aws.s3.model.LoggingEnabled.ReadOnly] =
      AwsError.unwrapOptionField("loggingEnabled", loggingEnabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.BucketLoggingStatus
  ) extends zio.aws.s3.model.BucketLoggingStatus.ReadOnly {
    override val loggingEnabled
        : Option[zio.aws.s3.model.LoggingEnabled.ReadOnly] = scala
      .Option(impl.loggingEnabled())
      .map(value => zio.aws.s3.model.LoggingEnabled.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.BucketLoggingStatus
  ): zio.aws.s3.model.BucketLoggingStatus.ReadOnly = new Wrapper(impl)
}
